
#ifndef GDHCPD_create_host_set_entries_H
#   define GDHCPD_create_host_set_entries_H

extern struct w *widgets;

void create_host_set_entries(struct w *widgets);

#endif
